@@ -5,7 +5,8 @@
 ds.package <- function(package, author, year, title, version, source)
 {
   ## 1  Bibliographic info: author, year, title, details
-  bib <- as.list(toBibtex(citation(package)[1]))
+  cit <- citation(package, lib.loc=c("bootstrap/library",.libPaths()))[1]
+  bib <- as.list(toBibtex(cit))
   key <- sub(",$", paste0(package,","), bib[[1]])  # add package name
   ## Treat null and NA (from mapply) the same, must test null first
   author <- if(is.null(author) || is.na(author)) bib$author
@@ -27,7 +28,7 @@ ds.package <- function(package, author, year, title, version, source)
                     c(bib$edition, bib$doi))
 
   ## 2  Package info: version, source
-  pkg <- packageDescription(package)
+  pkg <- packageDescription(package, lib.loc=c("bootstrap/library",.libPaths()))
   repotype <- if(isTRUE(pkg$Repository == "CRAN")) "CRAN"
               else if(isTRUE(pkg$RemoteType == "github")) "GitHub"
               else if(!is.null(pkg$Repository)) pkg$Repository
